@@ -106,63 +106,69 @@ class CassettePolling(threading.Thread):
         return rtn
 
     def manualQr(self):
-        status = DEVICE_STATE_CASSETTE_QR
-        qr = None
-#         if self.slotIndex ==0:
-#             print('slot', self.slotIndex, 'Operation',self.manual_sequence)
+        try:
+            status = DEVICE_STATE_CASSETTE_QR
+            qr = None
+            if self.slotIndex ==0:
+                print('slot', self.slotIndex, 'Operation',self.manual_sequence)
+                
+            if self.cassetteOut() and self.manual_sequence != MANUAL_OPERATION_TEST:
+                setOperation(self.slotIndex, MANUAL_OPERATION_START)
+    #            queueForGui.put([self.slotIndex, DEVICE_STATE_MANUAL_SCAN, '', 'cassette out'])
+    #            return status,qr
             
-        if self.cassetteOut() and self.manual_sequence != MANUAL_OPERATION_TEST:
-            setOperation(self.slotIndex, MANUAL_OPERATION_START)
-#            queueForGui.put([self.slotIndex, DEVICE_STATE_MANUAL_SCAN, '', 'cassette out'])
-#            return status,qr
-        
-        self.manual_sequence = getOperation(self.slotIndex)
-        
-        if self.manual_sequence  == MANUAL_OPERATION_START:
-            self.stopTakePhotoProcedure()
-            self.notify([self.slotIndex, DEVICE_STATE_MANUAL_SCAN, '', 'manual scan'])
-            setOperation(self.slotIndex, MANUAL_OPERATION_START_WAITING)
-        if self.manual_sequence  == MANUAL_OPERATION_START_WAITING:
-            pass
-        elif self.manual_sequence  == MANUAL_OPERATION_SCAN:
-            self.startTakePhotoProcedure(None,self.qrcode_que)
-            self.notify([self.slotIndex, DEVICE_STATE_MANUAL_GETTING_QR, '', 'getting id'])
-            self.qrPollingStamp=time.time()
-            setOperation(self.slotIndex, MANUAL_OPERATION_GETTING_QR)
-        elif self.manual_sequence  == MANUAL_OPERATION_GETTING_QR:
-            qr = self.qrcode_que.get()
-            if qr!=None:
-                if qr != NON_QR:
-                    print('got qr from image',qr)
-                    self.qrCode = qr
-                    setOperation(self.slotIndex, MANUAL_OPERATION_TEST)
-                    self.notify([self.slotIndex, DEVICE_STATE_MANUAL_FLIP, self.qrCode, 'Waiting test'])
-                else:
-                    self.notify([self.slotIndex, DEVICE_STATE_MANUAL_INVALID_QR, '', 'invalid qr'])
+            self.manual_sequence = getOperation(self.slotIndex)
+            
+            if self.manual_sequence  == MANUAL_OPERATION_START:
+                self.stopTakePhotoProcedure()
+                self.notify([self.slotIndex, DEVICE_STATE_MANUAL_SCAN, '', 'manual scan'])
+                setOperation(self.slotIndex, MANUAL_OPERATION_START_WAITING)
+            if self.manual_sequence  == MANUAL_OPERATION_START_WAITING:
+                pass
+            elif self.manual_sequence  == MANUAL_OPERATION_SCAN:
+                self.startTakePhotoProcedure(None,self.qrcode_que)
+                self.notify([self.slotIndex, DEVICE_STATE_MANUAL_GETTING_QR, '', 'getting id'])
+                self.qrPollingStamp=time.time()
+                setOperation(self.slotIndex, MANUAL_OPERATION_GETTING_QR)
+            elif self.manual_sequence  == MANUAL_OPERATION_GETTING_QR:
+                qr = self.qrcode_que.get()
+                if qr!=None:
+                    if qr != NON_QR:
+                        print('got qr from image',qr)
+                        self.qrCode = qr
+                        setOperation(self.slotIndex, MANUAL_OPERATION_TEST)
+                        self.notify([self.slotIndex, DEVICE_STATE_MANUAL_FLIP, self.qrCode, 'Waiting test'])
+                    else:
+                        self.notify([self.slotIndex, DEVICE_STATE_MANUAL_INVALID_QR, '', 'invalid qr'])
+                        setOperation(self.slotIndex, MANUAL_OPERATION_RESTART)
+                        
+                elif (time.time()- self.qrPollingStamp) > QR_POLLING_TIMEOUT:
+                    print('getting qr time out')
+                    self.notify([self.slotIndex, DEVICE_STATE_MANUAL_INVALID_QR, '', 'scan timeout'])
                     setOperation(self.slotIndex, MANUAL_OPERATION_RESTART)
-                    
-            elif (time.time()- self.qrPollingStamp) > QR_POLLING_TIMEOUT:
-                print('getting qr time out')
-                self.notify([self.slotIndex, DEVICE_STATE_MANUAL_INVALID_QR, '', 'scan timeout'])
-                setOperation(self.slotIndex, MANUAL_OPERATION_RESTART)
-            else:
-                print('reading qr...')
-        elif self.manual_sequence  == MANUAL_OPERATION_TEST:
-            pass
-        elif self.manual_sequence  == MANUAL_OPERATION_START_TESTING:
-            status = DEVICE_STATE_CASSETTE_VALID
-            qr = self.qrCode
-            setOperation(self.slotIndex, MANUAL_OPERATION_START_WAITING_RESULT)  ##waiting for result
-        elif self.manual_sequence  == MANUAL_OPERATION_START_WAITING_RESULT:
-            pass
-        elif self.manual_sequence == MANUAL_OPERATION_RESTART:
-            pass
-        #print('manual qr')
-        return status, qr
+                else:
+                    print('reading qr...')
+            elif self.manual_sequence  == MANUAL_OPERATION_TEST:
+                pass
+            elif self.manual_sequence  == MANUAL_OPERATION_START_TESTING:
+                status = DEVICE_STATE_CASSETTE_VALID
+                qr = self.qrCode
+                setOperation(self.slotIndex, MANUAL_OPERATION_START_WAITING_RESULT)  ##waiting for result
+            elif self.manual_sequence  == MANUAL_OPERATION_START_WAITING_RESULT:
+                pass
+            elif self.manual_sequence == MANUAL_OPERATION_RESTART:
+                pass
+            #print('manual qr')
+            return status, qr
+        except Exception as err:
+            print("manualQr exception: ", err)
+            return DEVICE_STATE_SUBSYS_EXCEPTION, None
         
 
     def autoQr(self):
         try:
+            if self.slotIndex ==0:
+                print('slot', self.slotIndex, 'Operation',self.manual_sequence)
             qrCode=''
             status=DEVICE_STATE_CASSETTE_EMPTY
             for i in range(7):                
@@ -240,8 +246,8 @@ class CassettePolling(threading.Thread):
                 self.notify([self.slotIndex, status, '','Cassette error'])
             
     def periodPoll(self):
-        #if self.slotIndex == 0:
-        #print("Period poll", time.strftime('%Y%m%d%H%M%S'))
+#         if self.slotIndex == 0:
+#             print("Period poll", time.strftime('%Y%m%d%H%M%S'))
         try:
             if self.running:
                 self.deviceDeal()
